@@ -225,7 +225,7 @@ class DirtyRollersAugmentation(Augmentation):
       line_width = random.randint(self.line_width_range[0], self.line_width_range[1])
       rotate = random.choice([True, False])
 
-      if (not self.debug and rotate):
+      if (rotate):
         image = cv2.rotate(image, cv2.ROTATE_90_CLOCKWISE)
 
       image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
@@ -234,7 +234,7 @@ class DirtyRollersAugmentation(Augmentation):
       image = self.transform(self.apply_scanline_mask, image, mask, meta_mask).astype("uint8")
       image = cv2.cvtColor(image, cv2.COLOR_GRAY2BGR)
 
-      if (not self.debug and rotate):
+      if (rotate):
         image = cv2.rotate(image, cv2.ROTATE_90_COUNTERCLOCKWISE)
 
       metadata = dict()
@@ -522,9 +522,13 @@ class BrightnessAugmentation(Augmentation):
 
   def __call__(self, data, force=False):
     if (force or self.should_run()):
+
       img = data[self.layer][-1].result
       value = random.uniform(self.range[0], self.range[1])
+      if self.layer=="ink":
+        img=cv2.cvtColor(img,cv2.COLOR_GRAY2BGR)
       hsv = cv2.cvtColor(img.astype("uint8"),cv2.COLOR_BGR2HSV)
+
       hsv = np.array(hsv, dtype = np.float64)
       hsv[:,:,1] = hsv[:,:,1]*value
       hsv[:,:,1][hsv[:,:,1]>255]  = 255
@@ -532,6 +536,8 @@ class BrightnessAugmentation(Augmentation):
       hsv[:,:,2][hsv[:,:,2]>255]  = 255
       hsv = np.array(hsv, dtype = np.uint8)
       img = cv2.cvtColor(hsv, cv2.COLOR_HSV2BGR)
+      if self.layer == "ink":
+        img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
       data[self.layer].append(AugmentationResult(self, img))
 
 class LightingGradientAugmentation(Augmentation):
